import { Envelope } from "./envelope";
import { MessageSignature, RFC3161SignedTimestamp, VerificationMaterial } from "./sigstore_common";
import { TransparencyLogEntry } from "./sigstore_rekor";
/**
 * Various timestamped counter signatures over the artifacts signature.
 * Currently only RFC3161 signatures are provided. More formats may be added
 * in the future.
 */
export interface TimestampVerificationData {
    /**
     * A list of RFC3161 signed timestamps provided by the user.
     * This can be used when the entry has not been stored on a
     * transparency log, or in conjuction for a stronger trust model.
     * Clients MUST verify the hashed message in the message imprint
     * against the signature in the bundle.
     */
    rfc3161Timestamps: RFC3161SignedTimestamp[];
}
/**
 * VerificationData contains extra data that can be used to verify things
 * such as transparency and timestamp of the signature creation.
 * As this message can be either empty (no inclusion proof or timestamps), or a combination of
 * an arbitrarily number of transparency log entries and signed timestamps,
 * it is the client's responsibility to implement any required verification
 * policies.
 */
export interface VerificationData {
    /**
     * This is the inclusion promise and/or proof, where
     * the timestamp is coming from the transparency log.
     */
    tlogEntries: TransparencyLogEntry[];
    /** Timestamp verification data, over the artifact's signature. */
    timestampVerificationData: TimestampVerificationData | undefined;
}
export interface Bundle {
    /**
     * MUST be application/vnd.dev.sigstore.bundle+json;version=0.1
     * when encoded as JSON.
     */
    mediaType: string;
    verificationData: VerificationData | undefined;
    verificationMaterial: VerificationMaterial | undefined;
    content?: {
        $case: "messageSignature";
        messageSignature: MessageSignature;
    } | {
        $case: "dsseEnvelope";
        dsseEnvelope: Envelope;
    };
}
export declare const TimestampVerificationData: {
    fromJSON(object: any): TimestampVerificationData;
    toJSON(message: TimestampVerificationData): unknown;
};
export declare const VerificationData: {
    fromJSON(object: any): VerificationData;
    toJSON(message: VerificationData): unknown;
};
export declare const Bundle: {
    fromJSON(object: any): Bundle;
    toJSON(message: Bundle): unknown;
};
